package com.kgraph.graph.service.impl;

import java.util.List;
import java.util.Map;

import com.kgraph.common.utils.DateUtils;
import com.kgraph.common.utils.file.FileUtils;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.kgraph.graph.mapper.SourceFileMapper;
import com.kgraph.graph.domain.SourceFile;
import com.kgraph.graph.service.ISourceFileService;

/**
 * 源文件管理Service业务层处理
 * 
 * @author Allen
 * @date 2023-10-16
 */
@Service
public class SourceFileServiceImpl implements ISourceFileService 
{
    @Autowired
    private SourceFileMapper sourceFileMapper;

    /**
     * 查询源文件管理
     * 
     * @param id 源文件管理主键
     * @return 源文件管理
     */
    @Override
    public SourceFile selectSourceFileById(Long id)
    {
        return sourceFileMapper.selectSourceFileById(id);
    }

    /**
     * 查询源文件管理列表
     * 
     * @param sourceFile 源文件管理
     * @return 源文件管理
     */
    @Override
    public List<SourceFile> selectSourceFileList(SourceFile sourceFile)
    {
        return sourceFileMapper.selectSourceFileList(sourceFile);
    }

    /**
     * 新增源文件管理
     * 
     * @param sourceFile 源文件管理
     * @return 结果
     */
    @Override
    public int insertSourceFile(SourceFile sourceFile)
    {
        sourceFile.setCreateTime(DateUtils.getNowDate());
        if(StringUtils.isEmpty(sourceFile.getSourceFileName()) && StringUtils.isNotEmpty(sourceFile.getSourceFilePath())){
            sourceFile.setSourceFileName(FileUtils.getRealName(sourceFile.getSourceFilePath()));
        }
        sourceFile.setSourceFileType(FileUtils.getSuffix(sourceFile.getSourceFilePath()));
        return sourceFileMapper.insertSourceFile(sourceFile);
    }

    /**
     * 修改源文件管理
     * 
     * @param sourceFile 源文件管理
     * @return 结果
     */
    @Override
    public int updateSourceFile(SourceFile sourceFile)
    {
        sourceFile.setUpdateTime(DateUtils.getNowDate());
        sourceFile.setSourceFileType(FileUtils.getSuffix(sourceFile.getSourceFilePath()));
        return sourceFileMapper.updateSourceFile(sourceFile);
    }

    /**
     * 批量删除源文件管理
     * 
     * @param ids 需要删除的源文件管理主键
     * @return 结果
     */
    @Override
    public int deleteSourceFileByIds(Long[] ids)
    {
        return sourceFileMapper.deleteSourceFileByIds(ids);
    }

    /**
     * 删除源文件管理信息
     * 
     * @param id 源文件管理主键
     * @return 结果
     */
    @Override
    public int deleteSourceFileById(Long id)
    {
        return sourceFileMapper.deleteSourceFileById(id);
    }

    @Override
    public List getOptions() {
        return sourceFileMapper.getOptions();
    }
}
