package com.kgraph.graph.service.impl;

import java.util.List;
import com.kgraph.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.kgraph.graph.mapper.SubtaskMapper;
import com.kgraph.graph.domain.Subtask;
import com.kgraph.graph.service.ISubtaskService;

/**
 * 子任务管理Service业务层处理
 * 
 * @author Allen
 * @date 2023-10-16
 */
@Service
public class SubtaskServiceImpl implements ISubtaskService 
{
    @Autowired
    private SubtaskMapper subtaskMapper;

    /**
     * 查询子任务管理
     * 
     * @param id 子任务管理主键
     * @return 子任务管理
     */
    @Override
    public Subtask selectSubtaskById(Long id)
    {
        return subtaskMapper.selectSubtaskById(id);
    }

    /**
     * 查询子任务管理列表
     * 
     * @param subtask 子任务管理
     * @return 子任务管理
     */
    @Override
    public List<Subtask> selectSubtaskList(Subtask subtask)
    {
        return subtaskMapper.selectSubtaskList(subtask);
    }

    /**
     * 新增子任务管理
     * 
     * @param subtask 子任务管理
     * @return 结果
     */
    @Override
    public int insertSubtask(Subtask subtask)
    {
        subtask.setCreateTime(DateUtils.getNowDate());
        return subtaskMapper.insertSubtask(subtask);
    }

    /**
     * 修改子任务管理
     * 
     * @param subtask 子任务管理
     * @return 结果
     */
    @Override
    public int updateSubtask(Subtask subtask)
    {
        subtask.setUpdateTime(DateUtils.getNowDate());
        return subtaskMapper.updateSubtask(subtask);
    }

    /**
     * 批量删除子任务管理
     * 
     * @param ids 需要删除的子任务管理主键
     * @return 结果
     */
    @Override
    public int deleteSubtaskByIds(Long[] ids)
    {
        return subtaskMapper.deleteSubtaskByIds(ids);
    }

    /**
     * 删除子任务管理信息
     * 
     * @param id 子任务管理主键
     * @return 结果
     */
    @Override
    public int deleteSubtaskById(Long id)
    {
        return subtaskMapper.deleteSubtaskById(id);
    }
}
